import os
import yaml
"""App Configuration"""

with open(os.path.join(os.path.abspath(os.path.dirname(__file__)),
                       '/etc/flask-auth/config.yml'), 'r') as f:
    doc = yaml.load(f)


class Auth:
    """Google Project Credentials"""

    CLIENT_ID = doc['google_creds']['CLIENT_ID']
    CLIENT_SECRET = doc['google_creds']['CLIENT_SECRET']

    REDIRECT_URI = '/oauth2callback'

    AUTH_URI = 'https://accounts.google.com/o/oauth2/auth'
    TOKEN_URI = 'https://accounts.google.com/o/oauth2/token'
    USER_INFO = 'https://www.googleapis.com/userinfo/v2/me'
    SCOPE = ['profile', 'email']


class Config:
    """Base config"""
    APP_NAME = "Flask Google Login"
    SECRET_KEY = os.environ.get("SECRET_KEY") or "somethingsecret"


class DevConfig(Config):
    """Dev config"""
    DEBUG = doc['DevConfig']['DEBUG']
    SQLALCHEMY_DATABASE_URI = 'sqlite:///' + os.path.join(
        os.path.abspath(os.path.dirname(__file__)),
        doc['DevConfig']['SQLALCHEMY_DATABASE_URI'])
    SQLALCHEMY_TRACK_MODIFICATIONS = doc['DevConfig'][
        'SQLALCHEMY_TRACK_MODIFICATIONS']
    OAUTH2_PROVIDER_TOKEN_EXPIRES_IN = doc['DevConfig'][
        'OAUTH2_PROVIDER_TOKEN_EXPIRES_IN']


class ProdConfig(Config):
    """Production config"""
    DEBUG = doc['ProdConfig']['DEBUG']
    SQLALCHEMY_DATABASE_URI = 'sqlite:///' + os.path.join(
        os.path.abspath(os.path.dirname(__file__)),
        doc['ProdConfig']['SQLALCHEMY_DATABASE_URI'])
    SQLALCHEMY_TRACK_MODIFICATIONS = doc['ProdConfig'][
        'SQLALCHEMY_TRACK_MODIFICATIONS']
    OAUTH2_PROVIDER_TOKEN_EXPIRES_IN = doc['ProdConfig'][
        'OAUTH2_PROVIDER_TOKEN_EXPIRES_IN']

config = {
    "dev": DevConfig,
    "prod": ProdConfig,
    "default": DevConfig
}

TRUSTED_PROXIES = doc['TRUSTED_PROXIES']
RUN_HOST = doc['RUN_HOST']
CONF_MODE = doc['CONF_MODE']
APP_SECRET_KEY = doc['APP_SECRET_KEY']
